pub struct MessageChannel { /* private fields */ }Expand description
Message channel for sending and receiving cloud events.
Implementations
Sourceimpl MessageChannel
impl MessageChannel
Returns a reference to the shared MessageChannel.
Sourcepub fn try_send(
&self,
message: impl Into<CloudEvent>,
) -> Result<(), TrySendError<CloudEvent>>
pub fn try_send( &self, message: impl Into<CloudEvent>, ) -> Result<(), TrySendError<CloudEvent>>
Attempts to send a message to all receivers in the channel except this one.
Sourcepub fn into_stream(self) -> impl Stream<Item = CloudEvent>
pub fn into_stream(self) -> impl Stream<Item = CloudEvent>
Consumes Self and returns a message stream of CloudEvent.